==> igniteui-angular-5.2.0-beta.0.tgz: package/README.md <==
# Ignite UI for Angular - from Infragistics

[![Build Status](https://travis-ci.org/IgniteUI/igniteui-angular.svg?branch=master)](https://travis-ci.org/IgniteUI/igniteui-angular)
[![Coverage Status](https://coveralls.io/repos/github/IgniteUI/igniteui-angular/badge.svg?branch=master)](https://coveralls.io/github/IgniteUI/igniteui-angular?branch=master)
[![npm version](https://badge.fury.io/js/igniteui-angular.svg)](https://badge.fury.io/js/igniteui-angular)

[Ignite UI for Angular](https://www.infragistics.com/products/ignite-ui-angular) is a complete set of Material-based UI Widgets, Components & Sketch UI kits and supporting directives for [Angular](https://angular.io/) by Infragistics.  Ignite UI for Angular is designed to enable developers to build the most modern, high-performance HTML5 & JavaScript apps for modern desktop browsers, mobile experiences and progressive web apps (PWA’s) targeting Google's Angular framework.  

You can find source files under the [`src`](https://github.com/IgniteUI/igniteui-angular/tree/master/src) folder, including samples and tests.

#### [**View running samples here**](https://www.infragistics.com/products/ignite-ui-angular/angular/components/grid.html)

**IMPORTANT** The repository has been renamed from `igniteui-js-blocks` to `igniteui-angular`. Read more on our new [naming convention](https://www.infragistics.com/community/blogs/b/infragistics/posts/ignite-ui-github-repo-name-changes). 

Current list of controls include:


| *Components*          | Status    | Docs                                                                                                           |     | *Directives*  | Status        | Docs                                                                                                      |
| :-:                   | :-:       | :-:                                                                                                            | :-: | :-:           | :-:           | :-:                                                                                                       |
| **avatar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/avatar/README.md)                        |     | **button**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/button/README.md)        |
| **badge**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/badge/README.md)                         |     | **filter**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/filter/README-FILTER.md) |
| **buttonGroup**       | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/buttonGroup/README.md)                   |     | **forOf**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/for-of/README.md)        |
| **calendar**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/tree/master/src/calendar/README.md)                      |     | **input**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/input/README.md)         |
| **card**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/card/README.md)                          |     | **label**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/label/README.md)         |
| **carousel**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/carousel/README.md)                      |     | **layout**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/layout/README.md)        |
| **checkbox**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/checkbox/README.md)                      |     | **ripple**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/ripple/README-RIPPLE.md) |
| **circular progress** | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/progressbar/README.md)                   |     | **toggle**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/toggle/README-TOGGLE.md) |
| **dataContainer**     | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/data-operations/README-DATACONTAINER.md) |     |               |               |                                                                                                           |
| **dataUtil**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/data-operations/README-DATAUTIL.md)      |     |               |               |                                                                                                           |
| **datePicker**        | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/date-picker/README.md)                   |     |               |               |                                                                                                           |
| **dialog**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/dialog/README.md)                        |     |               |               |                                                                                                           |
| **grid**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/grid/README.md)                          |     |               |               |                                                                                                           |
| **icon**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/tree/master/src/icon/README.md)                          |     |               |               |                                                                                                           |
| **linear progress**   | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/progressbar/README.md)                   |     |               |               |                                                                                                           |
| **list**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/list/README.md)                          |     |               |               |                                                                                                           |
| **navbar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/navbar/README.md)                        |     |               |               |                                                                                                           |
| **navigation drawer** | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/navigation-drawer/README.md)             |     |               |               |                                                                                                           |
| **radio**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/radio/README.md)                         |     |               |               |                                                                                                           |
| **scroll**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/scroll/README.md)                        |     |               |               |                                                                                                           |
| **slider**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/slider/README.md)                        |     |               |               |                                                                                                           |
| **snackbar**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/snackbar/README.md)                      |     |               |               |                                                                                                           |
| **switch**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/switch/README.md)                        |     |               |               |                                                                                                           |
| **tabbar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/tabbar/README.md)                        |     |               |               |                                                                                                           |
| **toast**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/toast/README.md)                         |     |               |               |                                                                                                           |

## Setup
From the root folder run:

```
npm install
```

## Getting Started with CLI
To get started with the Ignite UI CLI and Ignite UI for Angular:

```
npm i -g igniteui-cli
ig new <project name> --framework=angular
cd <project name>
ig add grid <component name>
ig start
```

## Build Library
In case your editor cannot auto-compile the TypeScript files (VS, VS Code, others with plugins)
there's a configured npm command in place to run the compiler:

For both ESM and UMD builds
```
npm run build
npm run build:watch // run in watch mode
```

ESM build only
```
npm run build:esm
npm run build:esm:watch // run in watch mode
```

UMD build only
```
npm run build:umd
npm run build:umd:watch // run in watch mode
```

## Run Demos

The `demos` directory contains a sample application showcasing the components and directives of the library.
If you want to run the application make sure to install the application dependencies:
```
cd demos && npm install
```

Run the following command from the root directory of your repository.
This will open the demos application in your preferred browser. Any changes in the
application code will trigger a rebuild of the application.
```
cd ..
npm run start:demos
```

In case you want to explore/experiment with the library code start the demo application
with:
```
npm run start:dev
```
It will watch both the `src` and `demos` directories and will rebuild both the library and the application.

## NPM Package

You can include Ignite UI for Angular in your project as a dependency using the NPM package.

`npm install igniteui-angular --save-dev`

## Contributing
[Coding Guidelines](../../wiki//Coding-guidelines-for-Ignite-UI-JS-Blocks)

[General Naming Guidelines](../../wiki//General-Naming-Guidelines-for-Ignite-UI-JS-Blocks)


## Quickstart App
[Ignite UI for Angular Quickstart app](https://github.com/IgniteUI/igniteui-angular-quickstart)
This repository is a fork of the Angular QuickStart Source and has been updated to demonstrate how to include and use components from Ignite UI for Angular. It basically follows the shortest path to bootstrap writing the application with Ignite UI for Angular:

- Fork the [the angular quickstart](https://github.com/angular/quickstart)
- Install Ignite UI for Angular from npm using `npm install igniteui-angular --save-dev`
- Update the views with sample Ignite UI for Angular controls.

## Demo Apps & Documentation
The [Warehouse Picklist App](https://github.com/IgniteUI/warehouse-js-blocks) demonstrates using several Ignite UI for Angular widgets together to build a modern, mobile app.

To get started with the Data Grid, use the steps in the [grid walk-through](https://www.infragistics.com/angular-samples/components/grid.html).  

All help, related API documents and walk-throughs can be found for each control [here](https://www.infragistics.com/angular-samples/components/grid.html). 

## Roadmap
[Roadmap document](https://github.com/IgniteUI/igniteui-angular/blob/master/ROADMAP.md)

## Support
Developer support is provided as part of the commercial, paid-for license via [Infragistics Forums](https://www.infragistics.com/community/forums/), or via Chat & Phone with a Priority Support license.  To acquire a license for paid support or Prioroty Support, please visit this [page](https://www.infragistics.com/how-to-buy/product-pricing#developers).

Community support for open source usage of this product is available at [StackOverflow](https://stackoverflow.com/questions/tagged/ignite-ui-angular).

Infragistics is only successful if you are successful, if you need additional assitance beyond our help documentation, forums or Prioroty Support, we have a full suite of Services offerings, including Angular Training, Application Architecture and Development and full Design Consultation.  Click to learn more about our [Services offerings](https://www.infragistics.com/consulting#popular-services).

## License
This project is released under the Apache License, version 2.0.  This is a commercial product, requiring a valid paid-for license for commercial use.  This product is free to use for non-commercial applications, like non-profits and educational usage. 

To acquire a license for commercial usage, please register for a trial and acquire a license at [Infragistics.com/Angular](https://www.infragistics.com/products/ignite-ui-angular/getting-started).

© Copyright 2017 INFRAGISTICS. All Rights Reserved.  The Infragistics Ultimate license & copyright applies to this distribution.  For information on that license, please go to our website [here](https://www.infragistics.com/legal/license).

==> igniteui-angular-5.3.0-beta.0.tgz: package/README.md <==
# Ignite UI for Angular - from Infragistics

[![Build Status](https://travis-ci.org/IgniteUI/igniteui-angular.svg?branch=master)](https://travis-ci.org/IgniteUI/igniteui-angular)
[![Coverage Status](https://coveralls.io/repos/github/IgniteUI/igniteui-angular/badge.svg?branch=master)](https://coveralls.io/github/IgniteUI/igniteui-angular?branch=master)
[![npm version](https://badge.fury.io/js/igniteui-angular.svg)](https://badge.fury.io/js/igniteui-angular)

[Ignite UI for Angular](https://www.infragistics.com/products/ignite-ui-angular) is a complete set of Material-based UI Widgets, Components & Sketch UI kits and supporting directives for [Angular](https://angular.io/) by Infragistics.  Ignite UI for Angular is designed to enable developers to build the most modern, high-performance HTML5 & JavaScript apps for modern desktop browsers, mobile experiences and progressive web apps (PWA’s) targeting Google's Angular framework.  

You can find source files under the [`src`](https://github.com/IgniteUI/igniteui-angular/tree/master/src) folder, including samples and tests.

#### [**View running samples here**](https://www.infragistics.com/products/ignite-ui-angular/angular/components/grid.html)

**IMPORTANT** The repository has been renamed from `igniteui-js-blocks` to `igniteui-angular`. Read more on our new [naming convention](https://www.infragistics.com/community/blogs/b/infragistics/posts/ignite-ui-github-repo-name-changes). 

Current list of controls include:


| *Components*          | Status    | Docs                                                                                                           |     | *Directives*  | Status        | Docs                                                                                                      |
| :-:                   | :-:       | :-:                                                                                                            | :-: | :-:           | :-:           | :-:                                                                                                       |
| **avatar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/avatar/README.md)                        |     | **button**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/button/README.md)        |
| **badge**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/badge/README.md)                         |     | **filter**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/filter/README-FILTER.md) |
| **buttonGroup**       | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/buttonGroup/README.md)                   |     | **forOf**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/for-of/README.md)        |
| **calendar**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/tree/master/src/calendar/README.md)                      |     | **input**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/input/README.md)         |
| **card**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/card/README.md)                          |     | **label**     |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/label/README.md)         |
| **carousel**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/carousel/README.md)                      |     | **layout**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/layout/README.md)        |
| **checkbox**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/checkbox/README.md)                      |     | **ripple**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/ripple/README-RIPPLE.md) |
| **circular progress** | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/progressbar/README.md)                   |     | **toggle**    |     Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/directives/toggle/README-TOGGLE.md) |
| **dataContainer**     | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/data-operations/README-DATACONTAINER.md) |     |               |               |                                                                                                           |
| **dataUtil**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/data-operations/README-DATAUTIL.md)      |     |               |               |                                                                                                           |
| **datePicker**        | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/date-picker/README.md)                   |     |               |               |                                                                                                           |
| **dialog**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/dialog/README.md)                        |     |               |               |                                                                                                           |
| **grid**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/grid/README.md)                          |     |               |               |                                                                                                           |
| **icon**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/tree/master/src/icon/README.md)                          |     |               |               |                                                                                                           |
| **linear progress**   | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/progressbar/README.md)                   |     |               |               |                                                                                                           |
| **list**              | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/list/README.md)                          |     |               |               |                                                                                                           |
| **navbar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/navbar/README.md)                        |     |               |               |                                                                                                           |
| **navigation drawer** | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/navigation-drawer/README.md)             |     |               |               |                                                                                                           |
| **radio**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/radio/README.md)                         |     |               |               |                                                                                                           |
| **slider**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/slider/README.md)                        |     |               |               |                                                                                                           |
| **snackbar**          | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/snackbar/README.md)                      |     |               |               |                                                                                                           |
| **switch**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/switch/README.md)                        |     |               |               |                                                                                                           |
| **tabbar**            | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/tabbar/README.md)                        |     |               |               |                                                                                                           |
| **toast**             | Available | [Readme](https://github.com/IgniteUI/igniteui-angular/blob/master/src/toast/README.md)                         |     |               |               |                                                                                                           |

## Setup
From the root folder run:

```
npm install
```

## Getting Started with CLI
To get started with the Ignite UI CLI and Ignite UI for Angular:

```
npm i -g igniteui-cli
ig new <project name> --framework=angular
cd <project name>
ig add grid <component name>
ig start
```

## Build Library
In case your editor cannot auto-compile the TypeScript files (VS, VS Code, others with plugins)
there's a configured npm command in place to run the compiler:

For both ESM and UMD builds
```
npm run build
npm run build:watch // run in watch mode
```

ESM build only
```
npm run build:esm
npm run build:esm:watch // run in watch mode
```

UMD build only
```
npm run build:umd
npm run build:umd:watch // run in watch mode
```

## Run Experimental Demos

The `demos` directory contains a sample application for development/experimental samples of the components and directives of the library.
If you want to run the demo application make sure to install the application dependencies:
```
cd demos && npm install
```

Run the following command from the root directory of your repository.
This will open the demos application in your preferred browser. Any changes in the
application code will trigger a rebuild of the application.
```
cd ..
npm run start:demos
```

In case you want to explore/experiment with the library code start the demo application
with:
```
npm run start:dev
```
It will watch both the `src` and `demos` directories and will rebuild both the library and the application.

**NOTE**: Experimental demos are not always stable.

## NPM Package

You can include Ignite UI for Angular in your project as a dependency using the NPM package.

`npm install igniteui-angular --save-dev`

## Contributing
[Coding Guidelines](../../wiki//Coding-guidelines-for-Ignite-UI-JS-Blocks)

[General Naming Guidelines](../../wiki//General-Naming-Guidelines-for-Ignite-UI-JS-Blocks)


## Quickstart App
[Ignite UI for Angular Quickstart app](https://github.com/IgniteUI/igniteui-angular-quickstart)
This repository is a fork of the Angular QuickStart Source and has been updated to demonstrate how to include and use components from Ignite UI for Angular. It basically follows the shortest path to bootstrap writing the application with Ignite UI for Angular:

- Fork the [the angular quickstart](https://github.com/angular/quickstart)
- Install Ignite UI for Angular from npm using `npm install igniteui-angular --save-dev`
- Update the views with sample Ignite UI for Angular controls.

## Demo Apps & Documentation
The [Warehouse Picklist App](https://github.com/IgniteUI/warehouse-js-blocks) demonstrates using several Ignite UI for Angular widgets together to build a modern, mobile app.

To get started with the Data Grid, use the steps in the [grid walk-through](https://www.infragistics.com/angular-samples/components/grid.html).  

All help, related API documents and walk-throughs can be found for each control [here](https://www.infragistics.com/angular-samples/components/grid.html). 

## Roadmap
[Roadmap document](https://github.com/IgniteUI/igniteui-angular/blob/master/ROADMAP.md)

## Support
Developer support is provided as part of the commercial, paid-for license via [Infragistics Forums](https://www.infragistics.com/community/forums/), or via Chat & Phone with a Priority Support license.  To acquire a license for paid support or Prioroty Support, please visit this [page](https://www.infragistics.com/how-to-buy/product-pricing#developers).

Community support for open source usage of this product is available at [StackOverflow](https://stackoverflow.com/questions/tagged/ignite-ui-angular).

Infragistics is only successful if you are successful, if you need additional assitance beyond our help documentation, forums or Prioroty Support, we have a full suite of Services offerings, including Angular Training, Application Architecture and Development and full Design Consultation.  Click to learn more about our [Services offerings](https://www.infragistics.com/consulting#popular-services).

## License
This project is released under the Apache License, version 2.0.  This is a commercial product, requiring a valid paid-for license for commercial use.  This product is free to use for non-commercial applications, like non-profits and educational usage. 

To acquire a license for commercial usage, please register for a trial and acquire a license at [Infragistics.com/Angular](https://www.infragistics.com/products/ignite-ui-angular/getting-started).

© Copyright 2017 INFRAGISTICS. All Rights Reserved.  The Infragistics Ultimate license & copyright applies to this distribution.  For information on that license, please go to our website [here](https://www.infragistics.com/legal/license).
